Module update

Module update 

Functions

create_branch
Create a new branch pointing to a commit
create_tag
Create a new tag pointing to a commit
delete_branch
Delete a branch reference
delete_tag
Delete a tag reference
list_branches
List all branch references
list_tags
List all tag references
read_reference
Read a reference and return the commit hash it points to
reference_exists
Check if a reference exists
update_branch
Update a branch reference
update_head
Update HEAD reference to point to a specific commit
update_reference
Update a Git reference to point to a specific commit
update_tag
Update a tag reference